@@ -74,10 +74,10 @@ void FilterImporterBalsa::parseFilter(const KConfigGroup &grp)
 void FilterImporterBalsa::parseCondition(const QString &condition, MailCommon::MailFilter *filter)
 {
     QStringList conditionList;
-    if (condition.startsWith(QLatin1String("OR "))) {
+    if (condition.startsWith(QLatin1StringView("OR "))) {
         conditionList = condition.split(QStringLiteral("OR"));
         filter->pattern()->setOp(SearchPattern::OpOr);
-    } else if (condition.startsWith(QLatin1String("AND "))) {
+    } else if (condition.startsWith(QLatin1StringView("AND "))) {
         conditionList = condition.split(QStringLiteral("AND"));
         filter->pattern()->setOp(SearchPattern::OpAnd);
     } else {
@@ -86,7 +86,7 @@ void FilterImporterBalsa::parseCondition(const QString &condition, MailCommon::M
     }
     for (QString cond : std::as_const(conditionList)) {
         cond = cond.trimmed();
-        if (cond.startsWith(QLatin1String("NOT"))) {
+        if (cond.startsWith(QLatin1StringView("NOT"))) {
             cond = cond.right(cond.length() - 3);
             cond = cond.trimmed();
         }
@@ -94,15 +94,15 @@ void FilterImporterBalsa::parseCondition(const QString &condition, MailCommon::M
 
         // Date between
         QByteArray fieldName;
-        if (cond.startsWith(QLatin1String("DATE"))) {
+        if (cond.startsWith(QLatin1StringView("DATE"))) {
             fieldName = "<date>";
             cond = cond.right(cond.length() - 4);
             cond = cond.trimmed();
             QStringList splitDate = cond.split(QLatin1Char(' '));
             qCDebug(MAILCOMMON_LOG) << " splitDate " << splitDate;
-        } else if (cond.startsWith(QLatin1String("FLAG"))) {
+        } else if (cond.startsWith(QLatin1StringView("FLAG"))) {
             qCDebug(MAILCOMMON_LOG) << " FLAG :";
-        } else if (cond.startsWith(QLatin1String("STRING"))) {
+        } else if (cond.startsWith(QLatin1StringView("STRING"))) {
             qCDebug(MAILCOMMON_LOG) << " STRING";
         } else {
             qCDebug(MAILCOMMON_LOG) << " condition not implemented :" << cond;
