@@ -22,7 +22,7 @@ using namespace MailCommon;
 
 RedirectWidget::RedirectWidget(QWidget *parent)
     : QWidget(parent)
-    , mEdit(new MessageComposer::ComposerLineEdit(true))
+    , mEdit(new MessageComposer::ComposerLineEdit(true, this))
 {
     auto hbox = new QHBoxLayout(this);
     hbox->setSpacing(0);
@@ -58,7 +58,7 @@ QString RedirectWidget::resend()
     return mResendStr;
 }
 
-void RedirectWidget::setFocus()
+void RedirectWidget::forceFocus()
 {
     mEdit->setFocus();
 }
@@ -83,7 +83,7 @@ void RedirectWidget::slotAddressSelection()
             addresses.prepend(mResendStr);
         }
 
-        mEdit->setText(addresses.join(QLatin1String(", ")));
+        mEdit->setText(addresses.join(QLatin1StringView(", ")));
         mEdit->setModified(true);
     }
 }
